#!/bin/sh
# simh-create-tarball.sh
#
# Check a parameter was passed
[[ ${#1} > 0 ]] || { echo "Usage $0 x.y-z"; exit 1; }

# Check all deps are present to run this script
for d in wget sed tar dos2unix; do
if rpm -q $d; then 
continue
else
echo "$d is required to run $0"
exit 1
fi
done

VERSION=$1
MAJOR=${VERSION:0:1}
MINOR=${VERSION:2:1}
PATCH=${VERSION:4:1}

# Download upstream tarball
wget https://github.com/simh/simh/archive/v$MAJOR.$MINOR-$PATCH.tar.gz

# Extract it
tar -xf "v$MAJOR.$MINOR-$PATCH.tar.gz"

# Remove unwanted roms, binaries and Visual Studio stuff
rm simh-$VERSION/VAX/ka655*
rm -Rf simh-$VERSION/Ibm1130
rm -rf "Visual Studio Projects"
sed -i -e "s/ ibm1130 / /" simh-$VERSION/makefile

# Change dos line endings in .txt files to unix
for i in $(find -name "*.txt"); do 
dos2unix -k "$i"
done

# Create distributable tarball
tar -czvf simh-$VERSION-noroms.tar.gz simh-$VERSION

# Tidy up
rm -f v$MAJOR.$MINOR-$PATCH.tar.gz
rm -rf simh-$MAJOR.$MINOR-$PATCH
